# May 25, 2021

**Date:** May 25, 2021, at 8am Pacific (your [timezone](https://arewemeetingyet.com/Los%20Angeles/2021-05-25/8:00/Jupyter%20Community%20Call))

[**Discourse**](https://discourse.jupyter.org/t/jupyter-community-calls/668)
[**YouTube Link**](https://youtu.be/g9WrS4FlkeM)

**Please note:**
- Community calls are recorded and posted to this [playlist](https://www.youtube.com/playlist?list=PLUrHeD2K9Cmkoamm4NjLmvXC4Y6E1o8SP)
- These notes will be recorded and posted [here](https://jupyter.readthedocs.io/en/latest/community/community-call-notes/index.html)
- Everyone present is held to the [Jupyter Code of Conduct](https://jupyter.org/conduct)

## Purpose

Think of it as a monthly, virtual JupyterCon. It’s a place to announce and share fun things happening in the Jupyter community.

For more discussion on the format of these calls, see the thread [here](https://discourse.jupyter.org/t/reviving-the-all-jupyter-team-meetings/423).

## Short reports, celebrations, shout-outs

* **Darian** Congratulations to the [2020 cohort of Jupyter Distinguished Contributors](https://blog.jupyter.org/congratulations-distinguished-contributors-149deff3033c)!
* **Nick** [ipydrawio 1.1.0](https://github.com/deathbeds/ipydrawio/releases/tag/v1.1.0) _just_ dropped: now has the `sketch` theme, a _Custom Diagram..._ Launcher which offers all of the (extensible) templates. Also [docs](https://ipydrawio.rtfd.io).
* **Steve** [JupyterLab 3.1.0a9](https://github.com/jupyterlab/jupyterlab/releases/tag/v3.1.0a9) is now available with Real Time Collaboration (RTC)!  To use:
    * Install
      * `pip install -U --pre jupyterlab` or
      * `conda install -c conda-forge -c conda-forge/label/jupyterlab_alpha jupyterlab=3.1.0a9`
    * Usage 
      * `jupyter lab --collaborative` or
      * Jupyter settings: `{"LabApp": {"collaborative": true, "expose_app_in_browser": true}}`
* **Isabela** Congratulations to all the community members who submitted CZI grant proposals last week! Thank you for your hard work.

## Agenda Items

* **Tony Fast** Searching notebooks
* RTC Demo with Live Binder (temporary link given in Zoom Chat, based on [Michał's example](https://mybinder.org/v2/gh/krassowski/jupyterlab-demo/rtc-demo?urlpath=lab)).  There is a "Share" top level menu item you can use to create the shareable link.
* **Nick** Learning with flashcards about... stuff?

## Other Links Shared

- https://github.com/jupyterlab/jupyterlab/blob/master/binder/start
- https://github.com/davidbrochart/jupyterlab-auth
- https://github.com/jtpio/jupyterlite/pull/89
- https://github.com/gt-coar/janki

## Attendees

| Institution                       | Name               | GitHub Handle     |
| --------------------------------- | ------------------ | ----------------- |
| University of Southern California | Dhrithi Deshpande  | @dhrithideshpande |
| Openteams                         | Eskild Eriksen     | @iameskild        |
| Two Sigma                         | Afshin T. Darian   | @afshin           |
| Georgia Tech                      | Nick Bollweg       | @bollwyvl         |
| Microsoft                         | Joyce Er           | @joyceerhl        |
| Microsoft                         | Claudia Regio      | @claudiaregio     |
| Microsoft                         | Paige Bailey       | @dynamicwebpaige  |
| UCSD                              | Thorin Tabor       | @tmtabor          |
| Alan Turing Institute             | Sarah Gibson       | @sgibson91        |
| QuantStack                        | Frederic Collonval | @fcollonval       |
| Quansight                         | Mars Lee           | @marsbarlee       |
| Jupyter/Noteable                  | Carol Willing      | @willingc         |
| QuantStack                        | Jeremy Tuloup      | @jtpio            |
| QuantStack                        | David Brochart     | @davidbrochart    |
| Apple                             | Steven Silvester   | @blink1073        |
| Apple                             | Zach Sailer        | @Zsailer          | 
| Quansight                         | Tony Fast          | @tonyfast         |
| Quansight Labs                    | Isabela Presedo-Floyd | @isabela-pf    |
| uPlanner                          | Sebastian Flores   |    @sebastiandres |
